@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.18.0";
+our $VERSION = "v6.19.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 77 of the 100+ operators in rxjs are implemented in this module.
+Currently 81 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -221,6 +221,26 @@ L<https://rxjs.dev/api/index/function/generate>
         sub ($x) { $x ** 2 + 1 }, # optional, and could also use $_ here
     )->subscribe($observer);
 
+=item rx_iif
+
+L<https://rxjs.dev/api/index/function/iif>
+
+    my $i;
+
+    my $o = rx_iif(
+        sub { $i > 5 },
+        rx_of(1, 2, 3),
+        rx_of(10, 20, 30),
+    );
+
+    $i = 4;
+    # 10, 20, 30, complete
+    $o->subscribe($observer);
+
+    $i = 6;
+    # 1, 2, 3, complete
+    $o->subscribe($observer);
+
 =item rx_interval
 
 L<https://rxjs.dev/api/index/function/interval>
@@ -680,6 +700,37 @@ order ('f2' first).
         $s->unsubscribe;
     });
 
+=item op_find
+
+L<https://rxjs.dev/api/operators/find>
+
+    # 7, complete
+    rx_interval(0.7)->pipe(
+        op_find(sub ($val, $idx) { $val == 7 }), # could use $_ here
+    )->subscribe($observer);
+
+    # undef, complete
+    rx_interval(0.7)->pipe(
+        op_take(5),
+        op_find(sub { $_ == 7 }),
+    )->subscribe($observer);
+
+=item op_find_index
+
+L<https://rxjs.dev/api/operators/findIndex>
+
+    # 7, complete
+    rx_interval(0.7)->pipe(
+        op_map(sub { $_ * 2 }),
+        op_find_index(sub ($val, $idx) { $val == 14 }), # could use $_ here
+    )->subscribe($observer);
+
+    # -1, complete
+    rx_interval(0.7)->pipe(
+        op_take(5),
+        op_find_index(sub { $_ == 7 }),
+    )->subscribe($observer);
+
 =item op_first
 
 L<https://rxjs.dev/api/operators/first>
@@ -712,6 +763,23 @@ L<https://rxjs.dev/api/operators/ignoreElements>
         op_ignore_elements(),
     )->subscribe($observer);
 
+=item op_is_empty
+
+L<https://rxjs.dev/api/operators/isEmpty>
+
+Same as rxjs's I<isEmpty>, but emits 1 or 0 instead of true or false.
+
+    # (pause 1 second) 0, complete
+    rx_interval(1)->pipe(
+        op_is_empty(),
+    )->subscribe($observer);
+
+    # (pause 2 seconds) 1, complete
+    rx_timer(2)->pipe(
+        op_ignore_elements(),
+        op_is_empty(),
+    )->subscribe($observer);
+
 =item op_map
 
 L<https://rxjs.dev/api/operators/map>
