@@ -16,12 +16,12 @@ use List::Util 'first';
 use Exporter 'import';
 our @EXPORT_OK = qw/
     rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY rx_fork_join rx_from rx_from_event
-    rx_from_event_array rx_generate rx_interval rx_merge rx_NEVER rx_observable rx_of rx_on_error_resume_next
+    rx_from_event_array rx_generate rx_iif rx_interval rx_merge rx_NEVER rx_observable rx_of rx_on_error_resume_next
     rx_partition rx_race rx_range rx_replay_subject rx_subject rx_throw_error rx_timer rx_zip
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.18.0";
+our $VERSION = "v6.19.0";
 
 sub rx_observable;
 
@@ -359,6 +359,14 @@ sub rx_generate {
     });
 }
 
+sub rx_iif {
+    my ($condition, $true_result, $false_result) = @_;
+
+    return rx_defer(sub {
+        return $condition->() ? $true_result : $false_result;
+    });
+}
+
 sub rx_interval {
     my ($after) = @_;
 
