@@ -18,14 +18,14 @@ our @EXPORT_OK = qw/
     op_audit_time op_buffer op_buffer_count op_buffer_time op_catch_error op_combine_latest_with op_concat_all
     op_concat_map op_concat_with op_count op_debounce_time op_default_if_empty op_delay op_distinct_until_changed
     op_distinct_until_key_changed op_element_at op_end_with op_every op_exhaust_all op_exhaust_map op_filter
-    op_finalize op_first op_ignore_elements op_map op_map_to op_merge_all op_merge_map op_merge_with op_multicast
-    op_on_error_resume_next_with op_pairwise op_pluck op_reduce op_ref_count op_repeat op_retry op_sample_time op_scan
-    op_share op_skip op_skip_until op_skip_while op_start_with op_switch_all op_switch_map op_take op_take_until
-    op_take_while op_tap op_throttle_time op_with_latest_from op_zip_with
+    op_finalize op_find op_find_index op_first op_ignore_elements op_is_empty op_map op_map_to op_merge_all
+    op_merge_map op_merge_with op_multicast op_on_error_resume_next_with op_pairwise op_pluck op_reduce op_ref_count
+    op_repeat op_retry op_sample_time op_scan op_share op_skip op_skip_until op_skip_while op_start_with op_switch_all
+    op_switch_map op_take op_take_until op_take_while op_tap op_throttle_time op_with_latest_from op_zip_with
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.18.0";
+our $VERSION = "v6.19.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -708,6 +708,64 @@ sub op_finalize {
     };
 }
 
+sub op_find {
+    my ($predicate) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        $predicate or return rx_throw_error('missing predicate in op_find');
+
+        return $source->pipe(
+            op_first($predicate),
+            op_default_if_empty(undef),
+        );
+    };
+}
+
+sub op_find_index {
+    my ($predicate) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        $predicate or return rx_throw_error('missing predicate in op_find_index');
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $idx = 0;
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    my ($val) = @_;
+                    my $truth;
+                    my $ok = eval {
+                        local $_ = $val;
+                        $truth = $predicate->($val, $idx++);
+                        1
+                    };
+                    if (!$ok) {
+                        $subscriber->{error}->($@) if defined $subscriber->{error};
+                    }
+                    if ($truth) {
+                        $subscriber->{next}->($idx - 1) if defined $subscriber->{next};
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+                complete => sub {
+                    $subscriber->{next}->(-1) if defined $subscriber->{next};
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_first {
     my ($condition) = @_;
 
@@ -738,6 +796,18 @@ sub op_ignore_elements {
     }
 }
 
+sub op_is_empty {
+    return sub {
+        my ($source) = @_;
+
+        return $source->pipe(
+            op_first(),
+            op_map_to(0),
+            op_default_if_empty(1),
+        );
+    };
+}
+
 sub op_map {
     my ($mapping_sub) = @_;
 
